summaryrefslogtreecommitdiffstats
path: root/mod_perl.pl
diff options
context:
space:
mode:
Diffstat (limited to 'mod_perl.pl')
-rw-r--r--mod_perl.pl8
1 files changed, 4 insertions, 4 deletions
diff --git a/mod_perl.pl b/mod_perl.pl
index dd092d791..5840351f4 100644
--- a/mod_perl.pl
+++ b/mod_perl.pl
@@ -58,11 +58,11 @@ BEGIN { *CORE::GLOBAL::warn = \&Apache2::ServerRec::warn; }
Bugzilla::CGI->compile(qw(:cgi :push));
use Apache2::SizeLimit;
# This means that every httpd child will die after processing
# a CGI if it is taking up more than 1600MB of RAM all by itself,
# not counting RAM it is sharing with the other httpd processes.
if (Bugzilla->params->{'urlbase'} eq 'https://bugzilla.mozilla.org/') {
- Apache2::SizeLimit->set_max_unshared_size(600_000);
+ Apache2::SizeLimit->set_max_unshared_size(700_000);
} else {
Apache2::SizeLimit->set_max_unshared_size(250_000);
}
@@ -58,11 +58,11 @@ BEGIN { *CORE::GLOBAL::warn = \&Apache2::ServerRec::warn; }
Bugzilla::CGI->compile(qw(:cgi :push));
use Apache2::SizeLimit;
-# This means that every httpd child will die after processing
-# a CGI if it is taking up more than 1600MB of RAM all by itself,
-# not counting RAM it is sharing with the other httpd processes.
+# This means that every httpd child will die after processing a request if it
+# is taking up more than 700MB of RAM all by itself, not counting RAM it is
+# sharing with the other httpd processes.
if (Bugzilla->params->{'urlbase'} eq 'https://bugzilla.mozilla.org/') {